####
closedown.py
####
closedown 1.0.1

휴폐업조회 API for Python.

* requirements

  * Python 2.6+
  * linkhub

************
Installation
************

Install via pip:

::

    $ pip install closedown

Install from source:

::

    $ git clone git://github.com/linkhub-sdk/closedown.py.git
    $ cd closedown.py
    $ python setup.py install
